@@ -3,7 +3,7 @@
 # test/test_daemon.py
 # Part of ‘python-daemon’, an implementation of PEP 3143.
 #
-# Copyright © 2008–2015 Ben Finney <ben+python@benfinney.id.au>
+# Copyright © 2008–2016 Ben Finney <ben+python@benfinney.id.au>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the Apache License, version 2.0 as published by the
@@ -20,18 +20,13 @@ import sys
 import pwd
 import tempfile
 import resource
+import io
 import errno
 import signal
 import socket
 from types import ModuleType
 import collections
 import functools
-try:
-    # Standard library of Python 2.7 and later.
-    from io import StringIO
-except ImportError:
-    # Standard library of Python 2.6 and earlier.
-    from StringIO import StringIO
 
 import mock
 
@@ -234,7 +229,7 @@ class DaemonContext_TestCase(DaemonContext_BaseTestCase):
     def test_has_default_initgroups(self):
         """ Should have default `initgroups` option. """
         args = dict()
-        expected_value = True
+        expected_value = False
         instance = daemon.daemon.DaemonContext(**args)
         self.assertEqual(expected_value, instance.initgroups)
 
@@ -744,16 +739,9 @@ class DaemonContext_get_exclude_file_descriptors_TestCase(
         instance = self.test_instance
         instance.files_preserve = list(self.test_files.values())
         stream_files = self.stream_files_by_name
-        mock_fileno_method = mock.MagicMock(
-                spec=sys.__stdin__.fileno,
-                side_effect=ValueError)
         expected_result = self.test_file_descriptors.copy()
         for (pseudo_stream_name, pseudo_stream) in stream_files.items():
-            test_non_fd_stream = StringIO()
-            if not hasattr(test_non_fd_stream, 'fileno'):
-                # Python < 3 StringIO doesn't have ‘fileno’ at all.
-                # Add a method which raises an exception.
-                test_non_fd_stream.fileno = mock_fileno_method
+            test_non_fd_stream = io.StringIO()
             setattr(instance, pseudo_stream_name, test_non_fd_stream)
             stream_fd = pseudo_stream.fileno()
             expected_result.discard(stream_fd)
@@ -1105,26 +1093,39 @@ class change_process_owner_TestCase(scaffold.TestCase):
             mock_func_os_initgroups):
         """ Should specify the UID's username to ‘os.initgroups’. """
         args = self.test_args
+        args['initgroups'] = True
         expected_username = self.test_pwent.pw_name
         daemon.daemon.change_process_owner(**args)
         mock_func_os_initgroups.assert_called_with(expected_username, mock.ANY)
 
-    def test_changes_group_id_to_gid(
+    def test_sets_group_id_to_gid_using_initgroups(
             self,
             mock_func_os_setuid, mock_func_os_setgid,
             mock_func_os_initgroups):
-        """ Should change process GID to specified value. """
+        """ Should change process GID using ‘os.initgroups’. """
         args = self.test_args
+        args['initgroups'] = True
         expected_gid = self.test_gid
         daemon.daemon.change_process_owner(**args)
         mock_func_os_initgroups.assert_called_once_with(mock.ANY, expected_gid)
 
+    def test_changes_group_id_to_gid_using_setgid(
+            self,
+            mock_func_os_setuid, mock_func_os_setgid,
+            mock_func_os_initgroups):
+        """ Should change process GID using ‘os.setgid’. """
+        args = self.test_args
+        expected_gid = self.test_gid
+        daemon.daemon.change_process_owner(**args)
+        mock_func_os_setgid.assert_called_once_with(expected_gid)
+
     def test_calls_setgid_when_username_not_found(
             self,
             mock_func_os_setuid, mock_func_os_setgid,
             mock_func_os_initgroups):
         """ Should call ‘os.setgid’ when no username for the UID. """
         args = self.test_args
+        args['initgroups'] = True
         expected_gid = self.test_gid
         pwd.getpwuid.side_effect = KeyError("No such entry")
         daemon.daemon.change_process_owner(**args)
